@@ -7,7 +7,7 @@ from fontbro.subset import parse_unicodes
 from fontbro.utils import read_json, slugify
 
 from fontTools import unicodedata
-from fontTools.subset import Subsetter
+from fontTools.subset import Subsetter, Options as SubsetterOptions
 from fontTools.ttLib import TTFont, TTLibError
 from fontTools.varLib import instancer
 from fontTools.varLib.instancer import OverlapMode
@@ -16,7 +16,6 @@ from PIL import Image, ImageDraw, ImageFont
 
 import copy
 import fsutil
-import imagehash
 import itertools
 import math
 import os
@@ -27,7 +26,7 @@ import tempfile
 
 class Font(object):
     """
-    friendly font operations.
+    friendly font operations on top of fontTools.
     """
 
     # Features:
@@ -240,6 +239,12 @@ class Font(object):
     def __exit__(self, e_type, e_value, e_traceback):
         self.close()
 
+    def clone(self):
+        """
+        Creates a new Font instance reading the same binary file.
+        """
+        return Font(self._filepath)
+
     def close(self):
         """
         Close the wrapped TTFont instance.
@@ -325,18 +330,58 @@ class Font(object):
         Gets the font fingerprint: an hash calculated from an image representation of the font.
         Changing the text option affects the returned fingerprint.
 
-        :param text: The text used for generating the fingerprint, default value: "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789"
+        :param text: The text used for generating the fingerprint, default value: "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789".
         :type text: str
 
         :returns: The fingerprint hash.
         :rtype: imagehash.ImageHash
         """
+        import imagehash
+
         text = text or "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789"
-        img = self.get_image(text=text, size=72)
+
+        img = self.get_image(text=text[0], size=72)
+        img_size = img.size
+        img = img.resize((img_size[0] // 2, img_size[1] // 2))
+        img = img.resize((img_size[0], img_size[1]), Image.NEAREST)
+        img = img.quantize(colors=2)
         # img.show()
-        hash = imagehash.dhash(img, hash_size=32)
+
+        hash = imagehash.average_hash(img, hash_size=64)
         return hash
 
+    def get_fingerprint_match(self, other, tolerance=10, text=""):
+        """
+        Gets the fingerprint match between this font and another one.
+        by checking if their fingerprints are equal (difference <= tolerance).
+
+        :param other: The other font, can be either a filepath or a Font instance.
+        :type other: str or Font
+        :param tolerance: The diff tolerance, default 3.
+        :type tolerance: int
+        :param text: The text used for generating the fingerprint, default value: "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789".
+        :type text: str
+
+        :returns: A tuple containing the match info (match, diff, hash, other_hash).
+        :rtype: tuple
+        """
+        other_font = None
+        if isinstance(other, str):
+            other_font = Font(other)
+        elif isinstance(other, Font):
+            other_font = other
+        else:
+            other_type = type(other).__name__
+            raise ValueError(
+                f"Invalid other filepath/font: expected str or Font instance, found '{other_type}'."
+            )
+        hash = self.get_fingerprint(text=text)
+        other_hash = other_font.get_fingerprint(text=text)
+        diff = hash - other_hash
+        match = diff <= tolerance
+        match = match and self.is_variable() == other_font.is_variable()
+        return (match, diff, hash, other_hash)
+
     def get_format(self, ignore_flavor=False):
         """
         Gets the font format: otf, ttf, woff, woff2.
@@ -378,6 +423,9 @@ class Font(object):
         :type color: tuple
         :param background_color: The background color
         :type background_color: tuple
+
+        :returns: The image.
+        :rtype: PIL.Image
         """
         with tempfile.TemporaryDirectory() as dest:
             filepath = self.save(dest)
@@ -722,6 +770,18 @@ class Font(object):
                 closest_instance = instance
         return closest_instance
 
+    def get_version(self):
+        """
+        Gets the font version.
+
+        :returns: The font version value.
+        :rtype: float
+        """
+        font = self.get_ttfont()
+        head = font.get("head")
+        version = head.fontRevision
+        return version
+
     def get_weight(self):
         """
         Gets the font weight value and name.
@@ -780,36 +840,6 @@ class Font(object):
         font = self.get_ttfont()
         return "fvar" in font
 
-    def match(self, other, tolerance=5):
-        """
-        Check if the font has the same "identity" of another font
-        by checking if the fingerprints difference is <= tolerance.
-
-        :param other: The other font, can be either a filepath or a Font instance.
-        :type other: str or Font
-        :param tolerance: The diff tolerance, default 3.
-        :type tolerance: int
-
-        :returns: True if match other font, False otherwise.
-        :rtype: bool
-        """
-        other_font = None
-        if isinstance(other, str):
-            other_font = Font(other)
-        elif isinstance(other, Font):
-            other_font = other
-        else:
-            other_type = type(other).__name__
-            raise ValueError(
-                f"Invalid other filepath/font: expected str or Font instance, found '{other_type}'."
-            )
-        if self.is_variable() != other_font.is_variable():
-            return False
-        hash = self.get_fingerprint()
-        other_hash = other_font.get_fingerprint()
-        hash_diff = hash - other_hash
-        return hash_diff <= tolerance
-
     def rename(self, family_name="", style_name=""):
         """
         Renames the font names records (1, 2, 4, 6, 16, 17) according to
@@ -1052,9 +1082,13 @@ class Font(object):
                 " glyphs, text."
             )
         unicodes = parse_unicodes(unicodes)
+        options.setdefault("layout_features", ["*"])
+        options.setdefault("name_IDs", "*")
+        options.setdefault("notdef_outline", True)
         subs_args = {"unicodes": unicodes, "glyphs": glyphs, "text": text}
         # https://github.com/fonttools/fonttools/blob/main/Lib/fontTools/subset/__init__.py
-        subs = Subsetter(**options)
+        subs_options = SubsetterOptions(**options)
+        subs = Subsetter(options=subs_options)
         subs.populate(**subs_args)
         subs.subset(font)
 
